Tutorials — powfacpy 0.0.1 documentation

# Tutorials

The tutorials are Jupyter notebooks which you can find here or click on the links below to go to a specific tutorial. You can use the PowerFactory project ‘powfacpy_test’ from here to run the commands in the tutorials locally.

## Getting started

Start here with the getting started tutorial. This tutorial gives an overview of the interaction with the PowerFactory database using powfacpy. The methods introduced in this tutorial serve as a basis to do more complex things and to write more readable code using less lines of code.

## Dynamic Simulation and Plotting

The tutorial shows how to conveniently simulate and plot with a syntax similar to matplotlib. It is also depicted how to export data to csv format and use external plotting libraries such as matplotlib.

## Study Cases

The study cases tutorial provides a flexible method to automatically create study cases from different data.